@@ -68,8 +68,9 @@ class Rethink_DBS(GeneralData):
             raise r_error
         except (socket.error, ConnectionResetError,
                 ConnectionAbortedError) as conn_error:
-            kwargs["origin_exception"] = socket.error
-            msg = f'''PD_TOA_-1 + {conn_error}, ConnectionClosed rc_enu connection....'''
+            msg = f'''PD_TOA_-1 + {conn_error}, ConnectionClosed rc_enu
+        connection....{{socket.error}}'''
+            kwargs["origin_exception"] = msg
             self.logger.exception(kwargs.get("origin_exception"))
             raise conn_error
         except Exception as ex:
@@ -168,7 +169,7 @@ class Rethink_DBS(GeneralData):
                     result = await self.r.db(dbname).table_create(
                         table_name).run(self.session)
                     await self.list_tables()
-                    return result
+                    return {"result":result,"created":True}
                 else:
                     self.logger.error("Table exists %s" % table_name)
                     msg = "Table Name %s exists" % table_name
@@ -256,27 +257,23 @@ class Rethink_DBS(GeneralData):
         try:
             if table_name in self.tables[self.defaultdb]:
                 task_coro = self.r.db(self.defaultdb).table(table_name).insert(
-                    data, durability='soft',
-                    return_changes=True).run(self.session)
+                    data, durability='soft').run(self.session)
                 return await task_coro
+            else:
+                return {"result": False}
         except asyncio.InvalidStateError as invalid_e:
             raise invalid_e
         except asyncio.CancelledError as ce:
             task = asyncio.current_task()
             self.logger.exception(
                 "Error de cancelación de tarea {result},{table_name}")
-            bprint(
-                f"Se cancela tarea para {table_name}, {filter_opt}, {result}")
             raise ce
-        except Exception as ec:
-            task = asyncio.current_task()
-            if task:
-                result = task.result()
+        except Exception as error:
             self.logger.critical(
                 "Error in saving data on %s with data %s, error %s" %
-                (table_name, data, ex))
-            print("Error when send data %s" % ex)
-            raise ex
+                (table_name, data, error))
+            print("Error when send data %s" % error)
+            raise error
 
     @property
     def dbname(self):
@@ -316,7 +313,6 @@ class Rethink_DBS(GeneralData):
         msg = "Extracting data between %s and %s from %s" % (lower, upper,
                                                              table_name)
         self.logger.info(msg)
-        bprint(msg)
         if table_name in self.tables[self.default_db]:
             return await self.r.db(dbname).table(table_name).between(
                 lower, upper).run(self.session)
@@ -324,7 +320,7 @@ class Rethink_DBS(GeneralData):
             print("No hay datos entre esos valores")
 
     async def get_data(self, table_name, index_name, value):
-        return await self.r.db(dbname).table(table_name).get_all(
+        return await self.r.db(self.dbname).table(table_name).get_all(
             value, index=index_name).run(self.session)
 
     async def get_data_filter(self,
