@@ -35,15 +35,20 @@ async def run(*args, **kwargs):
         await asyncio.sleep(5)
         postrdb = date_rdb()
         print(f"Desde {firstrdb}, hasta {postrdb}")
-        query = rdb.db("test").table(table).between(firstrdb, postrdb,
-                                                    **filter_opt).run(conn)
+        query = rdb.db("test").table(table).between(firstrdb,
+                                                    postrdb,
+                                                    left_bound='closed',
+                                                    right_bound='closed',
+                                                    index='DT_GEN').run(conn)
         result = await query
         print(result)
-    return [connected, postrdb, conn], kwargs
+        if result:
+            firstrdb = postrdb
+    return [connected, firstrdb, conn], kwargs
 
 
 connected = False
-now = date_rdb()
+now = date_rdb(-100)
 conn = None
 args = [connected, now, conn]
 kwargs: dict = {}
